civic\_scraper package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   civic_scraper.base
   civic_scraper.platforms

Submodules
----------

civic\_scraper.cli module
-------------------------

.. automodule:: civic_scraper.cli
   :members:
   :undoc-members:
   :show-inheritance:

civic\_scraper.runner module
----------------------------

.. automodule:: civic_scraper.runner
   :members:
   :undoc-members:
   :show-inheritance:

civic\_scraper.utils module
---------------------------

.. automodule:: civic_scraper.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: civic_scraper
   :members:
   :undoc-members:
   :show-inheritance:
